@@ -1,5 +1,7 @@
-/* Convert calendar time to simple time, inverse of mktime.
-   Copyright (C) 2003 Free Software Foundation, Inc.
+/* Convert UTC calendar time to simple time.  Like mktime but assumes UTC.
+
+   Copyright (C) 1994, 1997, 2003 Free Software Foundation, Inc.
+   This file is part of the GNU C Library.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,34 +17,26 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
-/* Get getenv declaration */
-#include <stdlib.h>
+#ifdef _LIBC
+# include <time.h>
+#else
+# include "timegm.h"
+# include <time_r.h>
+# undef __gmtime_r
+# define __gmtime_r gmtime_r
+time_t __mktime_internal (struct tm *,
+			  struct tm * (*) (time_t const *, struct tm *),
+			  time_t *);
+#endif
 
-/* Specification.  Get tzset and mktime declaration.  */
-#include "timegm.h"
-
-/* Get setenv and unsetenv declaration */
-#include "setenv.h"
-
-/* Convert calendar time to simple time, inverse of mktime. */
 time_t
-timegm (struct tm *tm)
+timegm (struct tm *tmp)
 {
-  time_t ret;
-  char *tz;
-
-  tz = getenv("TZ");
-  setenv("TZ", "", 1);
-  tzset();
-  ret = mktime(tm);
-  if (tz)
-    setenv("TZ", tz, 1);
-  else
-    unsetenv("TZ");
-  tzset();
-  return ret;
+  static time_t gmtime_offset;
+  tmp->tm_isdst = 0;
+  return __mktime_internal (tmp, __gmtime_r, &gmtime_offset);
 }
