@@ -1,5 +1,5 @@
 /* ap.c	AP functions
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -30,11 +30,27 @@ struct Shishi_ap
   Shishi_asn1 apreq;
   Shishi_asn1 aprep;
   Shishi_asn1 encapreppart;
-  int authenticatorcksumkeyusage;
+  /* Key usage for encryption entire Authenticator ASN.1 blob, stored
+     in AP-REQ. */
   int authenticatorkeyusage;
-  int authenticatorcksumtype;
+  /* Key usage for computing checksum of authenticatorcksumdata in the
+     Authenticator, in AP-REQ. */
+  int authenticatorcksumkeyusage;
+  /* Sets the checksum algorithm type in Authenticator, in AP-REQ.  If
+     there is data in authenticatorcksumdata to compute a checksum on,
+     this also indicate the algorithm to use for this computation. */
+  int32_t authenticatorcksumtype;
+  /* Auxilliary application data to compute checksum on and store in
+     Authenticator, in AP-REQ.  Note that data is not stored in
+     AP-REQ, only a checksum of it. */
   char *authenticatorcksumdata;
   size_t authenticatorcksumdatalen;
+  /* Raw checksum data to store in Authenticator, in AP-REQ.
+     Normally, this is the output of the checksum algorithm computed
+     on the data in authenticatorcksumdata, but some applications
+     (e.g., GSS-API) put something weird in the checksum field. */
+  char *authenticatorcksumraw;
+  size_t authenticatorcksumrawlen;
 };
 
 /**
@@ -180,6 +196,10 @@ shishi_ap_nosubkey (Shishi * handle, Shishi_ap ** ap)
 void
 shishi_ap_done (Shishi_ap * ap)
 {
+  if (ap->authenticatorcksumdata)
+    free (ap->authenticatorcksumdata);
+  if (ap->authenticatorcksumraw)
+    free (ap->authenticatorcksumraw);
   shishi_asn1_done (ap->handle, ap->authenticator);
   shishi_asn1_done (ap->handle, ap->apreq);
   shishi_asn1_done (ap->handle, ap->aprep);
@@ -250,6 +270,46 @@ shishi_ap_set_tktoptionsdata (Shishi_ap * ap,
   return SHISHI_OK;
 }
 
+
+/**
+ * shishi_ap_set_tktoptionsraw:
+ * @ap: structure that holds information about AP exchange
+ * @tkt: ticket to set in AP.
+ * @options: AP-REQ options to set in AP.
+ * @cksumtype: authenticator checksum type to set in AP.
+ * @data: input array with data to store in checksum field in Authenticator.
+ * @len: length of input array with data to store in checksum field in
+ *   Authenticator.
+ *
+ * Set the ticket (see shishi_ap_tkt_set()) and set the AP-REQ
+ * apoptions (see shishi_apreq_options_set()) and set the raw
+ * Authenticator checksum data.
+ *
+ * Return value: Returns SHISHI_OK iff successful.
+ **/
+int
+shishi_ap_set_tktoptionsraw (Shishi_ap * ap,
+			     Shishi_tkt * tkt,
+			     int options,
+			     int32_t cksumtype,
+			     const char *data, size_t len)
+{
+  int rc;
+
+  shishi_ap_tkt_set (ap, tkt);
+
+  rc = shishi_apreq_options_set (ap->handle, shishi_ap_req (ap), options);
+  if (rc != SHISHI_OK)
+    {
+      printf ("Could not set AP-Options: %s", shishi_strerror (rc));
+      return rc;
+    }
+
+  shishi_ap_authenticator_cksumraw_set (ap, cksumtype, data, len);
+
+  return SHISHI_OK;
+}
+
 /**
  * shishi_ap_set_tktoptionsasn1usage:
  * @ap: structure that holds information about AP exchange
@@ -363,6 +423,44 @@ shishi_ap_tktoptionsdata (Shishi * handle,
   return SHISHI_OK;
 }
 
+/**
+ * shishi_ap_tktoptionsraw:
+ * @handle: shishi handle as allocated by shishi_init().
+ * @ap: pointer to new structure that holds information about AP exchange
+ * @tkt: ticket to set in newly created AP.
+ * @options: AP-REQ options to set in newly created AP.
+ * @cksumtype: authenticator checksum type to set in AP.
+ * @data: input array with data to store in checksum field in Authenticator.
+ * @len: length of input array with data to store in checksum field in
+ *   Authenticator.
+ *
+ * Create a new AP exchange using shishi_ap(), and set the ticket,
+ * AP-REQ apoptions and the raw Authenticator checksum data field
+ * using shishi_ap_set_tktoptionsraw().  A random session key is added
+ * to the authenticator, using the same keytype as the ticket.
+ *
+ * Return value: Returns SHISHI_OK iff successful.
+ **/
+int
+shishi_ap_tktoptionsraw (Shishi * handle,
+			 Shishi_ap ** ap,
+			 Shishi_tkt * tkt, int options,
+			 int32_t cksumtype,
+			 const char *data, size_t len)
+{
+  int rc;
+
+  rc = shishi_ap_etype (handle, ap, shishi_tkt_keytype_fast (tkt));
+  if (rc != SHISHI_OK)
+    return rc;
+
+  rc = shishi_ap_set_tktoptionsraw (*ap, tkt, options, cksumtype, data, len);
+  if (rc != SHISHI_OK)
+    return rc;
+
+  return SHISHI_OK;
+}
+
 /**
  * shishi_ap_etype_tktoptionsdata:
  * @handle: shishi handle as allocated by shishi_init().
@@ -496,22 +594,51 @@ shishi_ap_authenticator_cksumdata (Shishi_ap * ap, char *out, size_t * len)
 /**
  * shishi_ap_authenticator_cksumdata_set:
  * @ap: structure that holds information about AP exchange
- * @authenticatorcksumdata: input array with authenticator checksum
- * data to use in AP.
- * @authenticatorcksumdatalen: length of input array with authenticator
- * checksum data to use in AP.
+ * @authenticatorcksumdata: input array with data to compute checksum
+ *   on and store in Authenticator in AP-REQ.
+ * @authenticatorcksumdatalen: length of input array with data to
+ *   compute checksum on and store in Authenticator in AP-REQ.
  *
- * Set the Authenticator Checksum Data in the AP exchange.
+ * Set the Authenticator Checksum Data in the AP exchange.  This is
+ * the data that will be checksumed, and the checksum placed in the
+ * checksum field.  It is not the actual checksum field.  See also
+ * shishi_ap_authenticator_cksumraw_set.
  **/
 void
 shishi_ap_authenticator_cksumdata_set (Shishi_ap * ap,
 				       const char *authenticatorcksumdata,
 				       size_t authenticatorcksumdatalen)
 {
-  ap->authenticatorcksumdata = authenticatorcksumdata;
+  ap->authenticatorcksumdata = xclone (authenticatorcksumdata,
+				       authenticatorcksumdatalen);
   ap->authenticatorcksumdatalen = authenticatorcksumdatalen;
 }
 
+/**
+ * shishi_ap_authenticator_cksumraw_set:
+ * @ap: structure that holds information about AP exchange
+ * @authenticatorcksumdata: input array with authenticator checksum
+ *   field value to set in Authenticator in AP-REQ.
+ * @authenticatorcksumdatalen: length of input array with
+ *   authenticator checksum field value to set in Authenticator in AP-REQ.
+ *
+ * Set the Authenticator Checksum Data in the AP exchange.  This is
+ * the actual checksum field, not data to compute checksum on and then
+ * store in the checksum field.  See also
+ * shishi_ap_authenticator_cksumdata_set.
+ **/
+void
+shishi_ap_authenticator_cksumraw_set (Shishi_ap * ap,
+				      int32_t authenticatorcksumtype,
+				      const char *authenticatorcksumraw,
+				      size_t authenticatorcksumrawlen)
+{
+  shishi_ap_authenticator_cksumtype_set (ap, authenticatorcksumtype);
+  ap->authenticatorcksumraw = xclone (authenticatorcksumraw,
+				      authenticatorcksumrawlen);
+  ap->authenticatorcksumrawlen = authenticatorcksumrawlen;
+}
+
 /**
  * shishi_ap_authenticatorcksumtype:
  * @ap: structure that holds information about AP exchange
@@ -520,7 +647,7 @@ shishi_ap_authenticator_cksumdata_set (Shishi_ap * ap,
  *
  * Return value: Return the authenticator checksum type.
  **/
-int
+int32_t
 shishi_ap_authenticator_cksumtype (Shishi_ap * ap)
 {
   return ap->authenticatorcksumtype;
@@ -534,7 +661,7 @@ shishi_ap_authenticator_cksumtype (Shishi_ap * ap)
  * Set the Authenticator Checksum Type in the AP exchange.
  **/
 void
-shishi_ap_authenticator_cksumtype_set (Shishi_ap * ap, int cksumtype)
+shishi_ap_authenticator_cksumtype_set (Shishi_ap * ap, int32_t cksumtype)
 {
   ap->authenticatorcksumtype = cksumtype;
 }
@@ -675,7 +802,12 @@ shishi_ap_req_build (Shishi_ap * ap)
     }
 
   cksumtype = shishi_ap_authenticator_cksumtype (ap);
-  if (cksumtype == SHISHI_NO_CKSUMTYPE)
+  if (ap->authenticatorcksumraw && ap->authenticatorcksumrawlen > 0)
+    res = shishi_authenticator_set_cksum (ap->handle, ap->authenticator,
+					  cksumtype,
+					  ap->authenticatorcksumraw,
+					  ap->authenticatorcksumrawlen);
+  else if (cksumtype == SHISHI_NO_CKSUMTYPE)
     res = shishi_authenticator_add_cksum (ap->handle, ap->authenticator,
 					  shishi_tkt_key (ap->tkt),
 					  ap->authenticatorcksumkeyusage,
@@ -825,6 +957,21 @@ shishi_ap_req_process_keyusage (Shishi_ap * ap,
   if (VERBOSEASN1 (ap->handle))
     shishi_authenticator_print (ap->handle, stdout, authenticator);
 
+  if (ap->authenticatorcksumdata)
+    free (ap->authenticatorcksumdata);
+
+  rc = shishi_authenticator_cksum (ap->handle, authenticator,
+				   &ap->authenticatorcksumtype,
+				   &ap->authenticatorcksumdata,
+				   &ap->authenticatorcksumdatalen);
+  if (rc != SHISHI_OK)
+    {
+      shishi_error_printf (ap->handle,
+			   "Error extracting authenticator checksum: %s\n",
+			   shishi_strerror (rc));
+      return rc;
+    }
+
   ap->authenticator = authenticator;
 
   return SHISHI_OK;
