@@ -1,4 +1,4 @@
-/* crypto.c	crypto functions
+/* crypto.c --- Crypto functions.
  * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of Shishi.
@@ -20,8 +20,13 @@
  */
 
 #include "internal.h"
+
+/* Get prototypes. */
 #include "crypto.h"
 
+/* Get _shishi_escapeprint, etc. */
+#include "utils.h"
+
 static int
 gcd (int a, int b)
 {
