@@ -1,4 +1,4 @@
-/* priv.c	Application data privacy protection.
+/* priv.c --- Application data privacy protection.
  * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of Shishi.
@@ -21,6 +21,9 @@
 
 #include "internal.h"
 
+/* Get _shishi_print_armored_data, etc. */
+#include "diskio.h"
+
 struct Shishi_priv
 {
   Shishi *handle;
