@@ -27,7 +27,7 @@
 #include <time.h>		/* time_t */
 #include <shishi-int.h>		/* uint32_t */
 
-#define SHISHI_VERSION "0.0.13"
+#define SHISHI_VERSION "0.0.14"
 
 /* Error codes */
 typedef enum
@@ -891,7 +891,7 @@ extern int shishi_authenticator_remove_cksum (Shishi * handle,
 extern int shishi_authenticator_cksum (Shishi * handle,
 				       Shishi_asn1 authenticator,
 				       int32_t * cksumtype,
-				       char *cksum, size_t * cksumlen);
+				       char **cksum, size_t * cksumlen);
 extern int shishi_authenticator_set_cksum (Shishi * handle,
 					   Shishi_asn1 authenticator,
 					   int cksumtype,
@@ -1642,6 +1642,16 @@ extern int shishi_ap_tktoptionsdata (Shishi * handle,
 				     Shishi_tkt * tkt,
 				     int options,
 				     const char *data, size_t len);
+extern int shishi_ap_set_tktoptionsraw (Shishi_ap * ap,
+					Shishi_tkt * tkt,
+					int options,
+					int32_t cksumtype,
+					const char *data, size_t len);
+extern int shishi_ap_tktoptionsraw (Shishi * handle,
+				    Shishi_ap ** ap,
+				    Shishi_tkt * tkt, int options,
+				    int32_t cksumtype,
+				    const char *data, size_t len);
 extern int shishi_ap_set_tktoptionsasn1usage (Shishi_ap * ap,
 					      Shishi_tkt * tkt,
 					      int options,
@@ -1667,9 +1677,14 @@ extern void
 shishi_ap_authenticator_cksumdata_set (Shishi_ap * ap,
 				       const char *authenticatorcksumdata,
 				       size_t authenticatorcksumdatalen);
-extern int shishi_ap_authenticator_cksumtype (Shishi_ap * ap);
+extern void
+shishi_ap_authenticator_cksumraw_set (Shishi_ap * ap,
+				      int32_t cksumtype,
+				      const char *authenticatorcksumraw,
+				      size_t authenticatorcksumrawlen);
+extern int32_t shishi_ap_authenticator_cksumtype (Shishi_ap * ap);
 extern void shishi_ap_authenticator_cksumtype_set (Shishi_ap * ap,
-						   int cksumtype);
+						   int32_t cksumtype);
 
 extern Shishi_asn1 shishi_ap_authenticator (Shishi_ap * ap);
 extern void shishi_ap_authenticator_set (Shishi_ap * ap,
