@@ -1,5 +1,5 @@
 /* shisa.c --- Command line interface to Shishi database.
- * Copyright (C) 2003  Simon Josefsson
+ * Copyright (C) 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -361,7 +361,14 @@ apply_options (const char *realm,
       etype = shishi_cfg_clientkdcetype_fast (sh);
 
       if (!salt && realm && principal)
-	asprintf (&salt, "%s%s", realm, principal);
+	{
+	  char *p;
+	  asprintf (&salt, "%s%s", realm, principal);
+
+	  /* FIXME: Parse principal/realm and create proper salt. */
+	  while ((p = strchr (salt, '/')))
+	    memmove (p, p + 1, strlen (p));
+	}
 
       if (args.string_to_key_parameter_given)
 	{
@@ -480,15 +487,15 @@ main (int argc, char *argv[])
       return EXIT_FAILURE;
     }
 
-  memset (&ph, 0, sizeof (ph));
-  memset (&key, 0, sizeof (key));
-  apply_options (realm, principal, &ph, &key);
-
   if (args.inputs_num > 0)
     realm = args.inputs[0];
   if (args.inputs_num > 1)
     principal = args.inputs[1];
 
+  memset (&ph, 0, sizeof (ph));
+  memset (&key, 0, sizeof (key));
+  apply_options (realm, principal, &ph, &key);
+
   if (args.list_given || args.dump_given)
     rc = dumplist ();
   else if (args.remove_given)
